@@ -975,15 +975,15 @@ class Askdata(SignUp):
         return ig.normalize_columns(df)
 
 
-    def save_dataset(self, df_input:pd.DataFrame, workspace: str, dataset_slug="", replace=True, dataset_name="", locale="en", skip_import_values=False):
+    def save_dataset(self, df:pd.DataFrame, workspace: str, dataset_slug="", replace=True, dataset_name="", locale="en", skip_import_values=False):
 
-        df = df_input.copy()
-        for col in df.columns:
-            if (df[col].dtypes == "datetime64[ns]"):
-                df[col] = df[col].astype("str").replace("NaT", None)
+        df_copy = df.copy()
+        for col in df_copy.columns:
+            if (df_copy[col].dtypes == "datetime64[ns]"):
+                df_copy[col] = df_copy[col].astype("str").replace("NaT", None)
 
         #df = df.where(pd.notnull(df), None)
-        df = self.normalize_columns(df)
+        df_copy = self.normalize_columns(df)
 
         if "/" in workspace:
             agentSlug = workspace.split("/")[0]
@@ -1007,7 +1007,7 @@ class Askdata(SignUp):
                 "Authorization": "Bearer" + " " + self._token
             }
             filename = dataset_slug + ".parquet"
-            df.to_parquet(filename)
+            df_copy.to_parquet(filename)
             response = s.put(url=url, files={"file": open(filename, 'rb')}, headers=headers)
             response.raise_for_status()
             dataset = response.json()
@@ -1024,7 +1024,7 @@ class Askdata(SignUp):
                 "Authorization": "Bearer" + " " + self._token
             }
             filename = dataset_slug + ".parquet"
-            df.to_parquet(filename)
+            df_copy.to_parquet(filename)
             response = s.post(url=url, files={"file": open(filename,'rb')}, headers=headers)
             response.raise_for_status()
             dataset = response.json()
