@@ -504,6 +504,21 @@ class Query:
                         string = '"' + field.aggregation.name + " " + field.sqlExpression + " AS " + field.alias + '"'
                     else:
                         string = '"' + field.sqlExpression + " AS " + field.alias + '"'
+            elif field.complexExpression is not None:
+                if field.alias is None:
+                    if field.aggregation is not None and isinstance(field.aggregation, str):
+                        string = '"' + field.aggregation + " " + field.complexExpression + '"'
+                    elif field.aggregation is not None and isinstance(field.aggregation, SQLFunction):
+                        string = '"' + field.aggregation.name + " " + field.complexExpression + '"'
+                    else:
+                        string = '"' + field.complexExpression + '"'
+                else:
+                    if field.aggregation is not None and isinstance(field.aggregation, str):
+                        string = '"' + field.aggregation + " " + field.complexExpression + " AS " + field.alias + '"'
+                    elif field.aggregation is not None and isinstance(field.aggregation, SQLFunction):
+                        string = '"' + field.aggregation.name + " " + field.complexExpression + " AS " + field.alias + '"'
+                    else:
+                        string = '"' + field.complexExpression + " AS " + field.alias + '"'
             else:
                 string = self._field_spell_out(field)
             fields.append(string)
