@@ -1,4 +1,4 @@
-from askdata import nlg
+from askdata import human2query
 import pandas as pd
 
 if __name__ == "__main__":
@@ -6,5 +6,5 @@ if __name__ == "__main__":
     df = df.append({'player': 'Cristiano Ronaldo', 'goals': 10, 'team': 'Juventus'}, ignore_index=True)
     df = df.append({'player': 'Roberto Baggio', 'goals': 2, 'team': 'Milan'}, ignore_index=True)
     examples = [["player=Cristiano Ronaldo, goals=3, team=Juventus", "Cristiano Ronaldo scored 3 goals for Juventus"]]
-    res = nlg.text_from_data(df=df, examples=examples, fit_items=False, max_tokens=64)
+    res = human2query.data2nl(df=df, examples=examples, fit_items=False, max_tokens=64)
     print(res)
